# data
from . import data
# classification
from . import classification
# regression
from . import linear_regression
# clustering
from . import clustering
# association
from . import association
